@@ -16,9 +16,8 @@ NULL
 #' @noRd
 #' @returns A logical value
 .is_eq <- function(x, y, tolerance = 0) {
-    if (tolerance[[1]] < 0) {
-        stop("invalid tolerance parameter")
-    }
+    .check_set_caller(".is_eq")
+    .check_that(tolerance >= 0)
     # Compute result and return
     all(abs(x - y) <= tolerance[[1]])
 }
@@ -26,9 +25,8 @@ NULL
 #' @noRd
 #' @returns A logical value
 .is_lt <- function(x, y, tolerance = 0) {
-    if (tolerance[[1]] < 0) {
-        stop("invalid tolerance parameter")
-    }
+    .check_set_caller(".is_lt")
+    .check_that(tolerance >= 0)
     # Compute result and return
     all(abs(y - x) > tolerance[[1]])
 }
@@ -36,9 +34,8 @@ NULL
 #' @noRd
 #' @returns A logical value
 .is_gt <- function(x, y, tolerance = 0) {
-    if (tolerance[[1]] < 0) {
-        stop("invalid tolerance parameter")
-    }
+    .check_set_caller(".is_gt")
+    .check_that(tolerance >= 0)
     # Compute result and return
     all(abs(x - y) > tolerance[[1]])
 }
