@@ -39,8 +39,6 @@
                                        stac_query,
                                        tiles = NULL,
                                        platform = NULL) {
-    # set caller to show in errors
-    .check_set_caller(".source_items_new.bdc_cube")
     # if specified, a filter per tile is added to the query
     if (!is.null(tiles)) {
         stac_query <- rstac::ext_query(q = stac_query, "bdc:tile" %in% tiles)
@@ -84,6 +82,6 @@
 .source_configure_access.bdc_cube <- function(source, collection = NULL) {
     bdc_access_key <- Sys.getenv("BDC_ACCESS_KEY")
     if (nchar(bdc_access_key) == 0)
-        Sys.setenv("BDC_ACCESS_KEY" = .conf("BDC_ACCESS_KEY"))
+        Sys.setenv(BDC_ACCESS_KEY = .conf("BDC_ACCESS_KEY"))
     return(invisible(source))
 }
