@@ -13,7 +13,8 @@
 #' (c) extreme gradient boosting: \code{\link[sits]{sits_xgboost}};
 #' (d) multi-layer perceptrons: \code{\link[sits]{sits_mlp}};
 #' (e) 1D CNN: \code{\link[sits]{sits_tempcnn}};
-#' (f) self-attention encoders: \code{\link[sits]{sits_lighttae}}.
+#' (f) self-attention encoders: \code{\link[sits]{sits_lighttae}} and
+#'  \code{\link[sits]{sits_tae}}
 #'
 #' @param  data              Data cube (tibble of class "raster_cube")
 #' @param  ml_model          R model trained by \code{\link[sits]{sits_train}}
@@ -24,6 +25,9 @@
 #'                           ("xmin", "xmax", "ymin", "ymax") or
 #'                           named lat/long values
 #'                           ("lon_min", "lat_min", "lon_max", "lat_max").
+#' @param  exclusion_mask    Areas to be excluded from the classification
+#'                           process. It can be defined as a sf object or a
+#'                           shapefile.
 #' @param  filter_fn         Smoothing filter to be applied - optional
 #'                           (closure containing object of class "function").
 #' @param  impute_fn         Imputation function to remove NA.
@@ -36,6 +40,7 @@
 #' @param  multicores        Number of cores to be used for classification
 #'                           (integer, min = 1, max = 2048).
 #' @param  gpu_memory        Memory available in GPU in GB (default = 4)
+#' @param  batch_size        Batch size for GPU classification.
 #' @param  n_sam_pol         Number of time series per segment to be classified
 #'                           (integer, min = 10, max = 50).
 #' @param  output_dir        Valid directory for output file.
@@ -62,18 +67,40 @@
 #'    are Savitzky-Golay (see \code{\link[sits]{sits_sgolay}}) and Whittaker
 #'    (see \code{\link[sits]{sits_whittaker}}) filters.
 #'
+#'    Parameter \code{impute_fn} defines a 1D function that will be used
+#'    to interpolate NA values in each time series. Currently sits supports
+#'    the \code{\link{impute_linear}} function, but users can define
+#'    imputation functions which are defined externally.
+#'
 #'    Parameter \code{memsize} controls the amount of memory available
 #'    for classification, while \code{multicores}  defines the number of cores
 #'    used for processing. We recommend using as much memory as possible.
 #'
+#'    Parameter \code{exclusion_mask} defines a region that will not be
+#'    classify. The region can be defined by multiple polygons.
+#'    Use an sf object or a shapefile to define it.
+#'
 #'    When using a GPU for deep learning, \code{gpu_memory} indicates the
-#'    memory of available in the graphics card.
+#'    memory of the graphics card which is available for processing.
+#'    The parameter \code{batch_size} defines the size of the matrix
+#'    (measured in number of rows) which is sent to the GPU for classification.
+#'    Users can test different values of \code{batch_size} to
+#'    find out which one best fits their GPU architecture.
+#'
 #'    It is not possible to have an exact idea of the size of Deep Learning
 #'    models in GPU memory, as the complexity of the model and factors
 #'    such as CUDA Context increase the size of the model in memory.
 #'    Therefore, we recommend that you leave at least 1GB free on the
 #'    video card to store the Deep Learning model that will be used.
 #'
+#'    For users of Apple M3 chips or similar with a Neural Engine, be
+#'    aware that these chips share memory between the GPU and the CPU.
+#'    Tests indicate that the \code{memsize}
+#'    should be set to half to the total memory and the \code{batch_size}
+#'    parameter should be a small number (we suggest the value of 64).
+#'    Be aware that increasing these parameters may lead to memory
+#'    conflicts.
+#'
 #'    For classifying vector data cubes created by
 #'    \code{\link[sits]{sits_segment}},
 #'    \code{n_sam_pol} controls is the number of time series to be
@@ -153,11 +180,7 @@
 #' }
 #'
 #' @export
-sits_classify <- function(data, ml_model, ...,
-                          filter_fn = NULL,
-                          multicores = 2L,
-                          progress = TRUE) {
-
+sits_classify <- function(data, ml_model, ...) {
     UseMethod("sits_classify", data)
 }
 
@@ -170,20 +193,21 @@ sits_classify.sits <- function(data,
                                impute_fn = impute_linear(),
                                multicores = 2L,
                                gpu_memory = 4,
+                               batch_size = 2^gpu_memory,
                                progress = TRUE) {
     # set caller for error messages
     .check_set_caller("sits_classify_sits")
     # Pre-conditions
-    data <- .check_samples_ts(data)
+    .check_samples_ts(data)
     .check_is_sits_model(ml_model)
     .check_int_parameter(multicores, min = 1, max = 2048)
     .check_progress(progress)
-    # Update multicores: xgb model does its own parallelization
-    if (inherits(ml_model, "xgb_model"))
-        multicores <- 1
-    # for MPS, set gpu memory to 1 GB
-    if (inherits(ml_model, "torch_model") && .torch_has_mps())
-        gpu_memory <- 1
+    .check_function(impute_fn)
+    .check_filter_fn(filter_fn)
+    # save batch_size for later use
+    sits_env[["batch_size"]] <- batch_size
+    # Update multicores
+    multicores <- .ml_update_multicores(ml_model, multicores)
     # Do classification
     classified_ts <- .classify_ts(
         samples = data,
@@ -202,6 +226,7 @@ sits_classify.sits <- function(data,
 sits_classify.raster_cube <- function(data,
                                       ml_model, ...,
                                       roi = NULL,
+                                      exclusion_mask = NULL,
                                       filter_fn = NULL,
                                       impute_fn = impute_linear(),
                                       start_date = NULL,
@@ -209,6 +234,7 @@ sits_classify.raster_cube <- function(data,
                                       memsize = 8L,
                                       multicores = 2L,
                                       gpu_memory = 4,
+                                      batch_size = 2^gpu_memory,
                                       output_dir,
                                       version = "v1",
                                       verbose = FALSE,
@@ -217,69 +243,62 @@ sits_classify.raster_cube <- function(data,
     .check_set_caller("sits_classify_raster")
     # preconditions
     .check_is_raster_cube(data)
-    .check_that(.cube_is_regular(data))
+    .check_cube_is_regular(data)
     .check_is_sits_model(ml_model)
-    .check_int_parameter(memsize, min = 1, max = 16384)
-    .check_int_parameter(multicores, min = 1, max = 2048)
+    .check_int_parameter(memsize, min = 1)
+    .check_int_parameter(multicores, min = 1)
+    .check_int_parameter(gpu_memory, min = 1)
     .check_output_dir(output_dir)
+    # preconditions - impute and filter functions
+    .check_function(impute_fn)
+    .check_filter_fn(filter_fn)
     # version is case-insensitive in sits
     version <- .check_version(version)
     .check_progress(progress)
-    # Get default proc bloat
-    proc_bloat <- .conf("processing_bloat_cpu")
-    # If we using the GPU, gpu_memory parameter needs to be specified
-    if (.torch_cuda_enabled(ml_model)) {
-        .check_int_parameter(gpu_memory, min = 1, max = 16384,
-                             msg = .conf("messages", ".check_gpu_memory")
-        )
-        # Calculate available memory from GPU
-        memsize <- floor(gpu_memory - .torch_mem_info())
-        .check_int_parameter(memsize, min = 1,
-                        msg = .conf("messages", ".check_gpu_memory_size")
-        )
-        proc_bloat <- .conf("processing_bloat_gpu")
-    }
-    # avoid memory race in Apple MPS
-    if(.torch_mps_enabled(ml_model)){
-        memsize <- 1
-        gpu_memory <- 1
-    }
-    # save memsize for latter use
-    sits_env[["gpu_memory"]] <- gpu_memory
     # Spatial filter
     if (.has(roi)) {
         roi <- .roi_as_sf(roi)
         data <- .cube_filter_spatial(cube = data, roi = roi)
     }
+    # Exclusion mask
+    if (.has(exclusion_mask))
+        exclusion_mask <- .mask_as_sf(exclusion_mask)
     # Temporal filter
-    if (.has(start_date) || .has(end_date)) {
-        data <- .cube_filter_interval(
-            cube = data, start_date = start_date, end_date = end_date
-        )
-    }
-    if (.has(filter_fn))
-        .check_filter_fn(filter_fn)
+    start_date <- .default(start_date, .cube_start_date(data))
+    end_date <- .default(end_date, .cube_end_date(data))
+    data <- .cube_filter_interval(
+        cube = data, start_date = start_date, end_date = end_date
+    )
+    # save batch_size for later use
+    sits_env[["batch_size"]] <- batch_size
+
     # Retrieve the samples from the model
     samples <- .ml_samples(ml_model)
-    # By default, base bands is null.
-    base_bands <- NULL
-    if (.cube_is_base(data)) {
-        # Get base bands
-        base_bands <- intersect(
-            .ml_bands(ml_model), .cube_bands(.cube_base_info(data))
-        )
-    }
-    # get non-base bands
-    bands <- setdiff(.ml_bands(ml_model), base_bands)
     # Do the samples and tile match their timeline length?
     .check_samples_tile_match_timeline(samples = samples, tile = data)
     # Do the samples and tile match their bands?
     .check_samples_tile_match_bands(samples = samples, tile = data)
+
+    # By default, base bands is null.
+    base_bands <- NULL
+    if (.cube_is_base(data))
+        # Get base bands
+        base_bands <- intersect(
+            .ml_bands(ml_model), .cube_bands(.cube_base_info(data))
+        )
+    # get non-base bands
+    bands <- setdiff(.ml_bands(ml_model), base_bands)
+
+    # Update multicores for models with internal parallel processing
+    multicores <- .ml_update_multicores(ml_model, multicores)
+
+    # The following functions define optimal parameters for parallel processing
+    #
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(data)))
     # Check minimum memory needed to process one block
-    job_memsize <- .jobs_memsize(
-        job_size = .block_size(block = block, overlap = 0),
+    job_block_memsize <- .jobs_block_memsize(
+        block_size = .block_size(block = block, overlap = 0),
         npaths = (
             length(.tile_paths(data, bands)) +
             length(.ml_labels(ml_model)) +
@@ -290,31 +309,22 @@ sits_classify.raster_cube <- function(data,
             )
         ),
         nbytes = 8,
-        proc_bloat = proc_bloat
+        proc_bloat = .conf("processing_bloat")
     )
-    # Update multicores parameter
-    if ("xgb_model" %in% .ml_class(ml_model))
-        multicores <- 1
-    else if (.torch_mps_enabled(ml_model) || .torch_cuda_enabled(ml_model))
-        multicores <- 1
-    else
-        # Update multicores parameter
-        multicores <- .jobs_max_multicores(
-            job_memsize = job_memsize,
-            memsize = memsize,
-            multicores = multicores
-        )
-    # Update block parameter
+    # Update multicores parameter based on size of a single block
+    multicores <- .jobs_max_multicores(
+        job_block_memsize = job_block_memsize,
+        memsize = memsize,
+        multicores = multicores
+    )
+    # Update block parameter based on the size of memory and number of cores
     block <- .jobs_optimal_block(
-        job_memsize = job_memsize,
+        job_block_memsize = job_block_memsize,
         block = block,
         image_size = .tile_size(.tile(data)),
         memsize = memsize,
         multicores = multicores
     )
-    # Terra requires at least two pixels to recognize an extent as valid
-    # polygon and not a line or point
-    block <- .block_regulate_size(block)
     # Prepare parallel processing
     .parallel_start(
         workers = multicores, log = verbose,
@@ -335,6 +345,7 @@ sits_classify.raster_cube <- function(data,
             ml_model = ml_model,
             block = block,
             roi = roi,
+            exclusion_mask = exclusion_mask,
             filter_fn = filter_fn,
             impute_fn = impute_fn,
             output_dir = output_dir,
@@ -348,28 +359,6 @@ sits_classify.raster_cube <- function(data,
     .classify_verbose_end(verbose, start_time)
     return(probs_cube)
 }
-
-#' @rdname sits_classify
-#' @export
-sits_classify.derived_cube <- function(data, ml_model, ...) {
-    stop(.conf("messages", "sits_classify_derived_cube"))
-}
-
-#' @rdname sits_classify
-#' @export
-sits_classify.tbl_df <- function(data, ml_model, ...) {
-    data <- tibble::as_tibble(data)
-    if (all(.conf("sits_cube_cols") %in% colnames(data))) {
-        data <- .cube_find_class(data)
-    } else if (all(.conf("sits_tibble_cols") %in% colnames(data))) {
-        class(data) <- c("sits", class(data))
-    } else {
-        stop(.conf("messages", "sits_classify_tbl_df"))
-    }
-    result <- sits_classify(data, ml_model, ...)
-    return(result)
-}
-
 #' @rdname sits_classify
 #' @export
 sits_classify.segs_cube <- function(data,
@@ -382,6 +371,7 @@ sits_classify.segs_cube <- function(data,
                                     memsize = 8L,
                                     multicores = 2L,
                                     gpu_memory = 4,
+                                    batch_size = 2^gpu_memory,
                                     output_dir,
                                     version = "v1",
                                     n_sam_pol = NULL,
@@ -397,80 +387,63 @@ sits_classify.segs_cube <- function(data,
     .check_int_parameter(memsize, min = 1, max = 16384)
     .check_int_parameter(multicores, min = 1, max = 2048)
     .check_output_dir(output_dir)
+    # preconditions - impute and filter functions
+    .check_function(impute_fn)
+    .check_filter_fn(filter_fn)
     # version is case-insensitive in sits
     version <- .check_version(version)
     .check_progress(progress)
-    proc_bloat <- .conf("processing_bloat_seg_class")
-    # If we using CUDA, gpu_memory parameter needs to be specified
-    if (.torch_cuda_enabled(ml_model)) {
-        .check_int_parameter(gpu_memory, min = 1, max = 16384,
-                             msg = .conf("messages", ".check_gpu_memory")
-        )
-        # Calculate available memory from GPU
-        memsize <- floor(gpu_memory - .torch_mem_info())
-        .check_int_parameter(memsize, min = 2,
-                             msg = .conf("messages", ".check_gpu_memory_size")
-        )
-        proc_bloat <- .conf("processing_bloat_gpu")
-    }
-    # avoid memory race in Apple MPS
-    if(.torch_mps_enabled(ml_model)){
-        memsize <- 1
-        gpu_memory <- 1
-    }
+
+    # save GPU memory info for later use
+    sits_env[["batch_size"]] <- batch_size
+
     # Spatial filter
     if (.has(roi)) {
         roi <- .roi_as_sf(roi)
         data <- .cube_filter_spatial(cube = data, roi = roi)
     }
     # Temporal filter
-    if (.has(start_date) || .has(end_date)) {
-        data <- .cube_filter_interval(
-            cube = data, start_date = start_date, end_date = end_date
-        )
-    }
-    if (.has(filter_fn))
-        .check_filter_fn(filter_fn)
-    # By default, base bands is null.
+    start_date <- .default(start_date, .cube_start_date(data))
+    end_date <- .default(end_date, .cube_end_date(data))
+    data <- .cube_filter_interval(
+        cube = data, start_date = start_date, end_date = end_date
+    )
+    # Check if cube has a base band
     base_bands <- NULL
-    if (.cube_is_base(data)) {
-        # Get base bands
+    if (.cube_is_base(data))
         base_bands <- intersect(
             .ml_bands(ml_model), .cube_bands(.cube_base_info(data))
         )
-    }
     # get non-base bands
     bands <- setdiff(.ml_bands(ml_model), base_bands)
-    # Check memory and multicores
+    # Update multicores for models with internal parallel processing
+    multicores <- .ml_update_multicores(ml_model, multicores)
+
+    # The following functions define optimal parameters for parallel processing
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(data)))
     # Check minimum memory needed to process one block
-    job_memsize <- .jobs_memsize(
-        job_size = .block_size(block = block, overlap = 0),
+    job_block_memsize <- .jobs_block_memsize(
+        block_size = .block_size(block = block, overlap = 0),
         npaths = length(.tile_paths(data)) + length(.ml_labels(ml_model)),
         nbytes = 8,
-        proc_bloat = proc_bloat
+        proc_bloat = .conf("processing_bloat")
     )
-    # Update multicores parameter
-    if ("xgb_model" %in% .ml_class(ml_model) || .is_torch_model(ml_model))
-        multicores <- 1
-    else
-        multicores <- .jobs_max_multicores(
-            job_memsize = job_memsize,
-            memsize = memsize,
-            multicores = multicores
-        )
-    # Update block parameter
+    # Update multicores parameter based on size of a single block
+    multicores <- .jobs_max_multicores(
+        job_block_memsize = job_block_memsize,
+        memsize = memsize,
+        multicores = multicores
+    )
+    # Update block parameter to find optimal size
+    # considering kind of model and use of CPU or GPU
     block <- .jobs_optimal_block(
-        job_memsize = job_memsize,
+        job_block_memsize = job_block_memsize,
         block = block,
         image_size = .tile_size(.tile(data)),
         memsize = memsize,
         multicores = multicores
     )
-    # Terra requires at least two pixels to recognize an extent as valid
-    # polygon and not a line or point
-    block <- .block_regulate_size(block)
     # Prepare parallel processing
     .parallel_start(
         workers = multicores, log = verbose,
@@ -502,7 +475,25 @@ sits_classify.segs_cube <- function(data,
     })
     return(probs_vector_cube)
 }
-
+#' @rdname sits_classify
+#' @export
+sits_classify.tbl_df <- function(data, ml_model, ...) {
+    data <- tibble::as_tibble(data)
+    if (all(.conf("sits_cube_cols") %in% colnames(data))) {
+        data <- .cube_find_class(data)
+    } else if (all(.conf("sits_tibble_cols") %in% colnames(data))) {
+        class(data) <- c("sits", class(data))
+    } else {
+        stop(.conf("messages", "sits_classify_tbl_df"))
+    }
+    result <- sits_classify(data, ml_model, ...)
+    return(result)
+}
+#' @rdname sits_classify
+#' @export
+sits_classify.derived_cube <- function(data, ml_model, ...) {
+    stop(.conf("messages", "sits_classify_derived_cube"))
+}
 #' @rdname sits_classify
 #' @export
 sits_classify.default <- function(data, ml_model, ...) {
