@@ -39,14 +39,8 @@ sits_to_csv.sits <- function(data, file = NULL) {
             extensions = "csv",
             file_exists = FALSE
         )
-    # select the parts of the tibble to be saved
-    csv_columns <- .conf("df_sample_columns")
-    csv <- dplyr::select(data, dplyr::all_of(csv_columns))
-    # create a column with the id
-    n_rows_csv <- nrow(csv)
-    id <- tibble::tibble(id = 1:n_rows_csv)
-    # join the two tibbles
-    csv <- dplyr::bind_cols(id, csv)
+    # get metadata
+    csv <- .csv_metadata_from_samples(data)
     # write the CSV file
     if (.has(file))
         utils::write.csv(csv, file, row.names = FALSE, quote = FALSE)
@@ -68,3 +62,42 @@ sits_to_csv.tbl_df <- function(data, file) {
 sits_to_csv.default <- function(data, file) {
     stop(.conf("messages", "sits_to_csv_default"))
 }
+#' @title Export a a full sits tibble to the CSV format
+#'
+#' @name sits_timeseries_to_csv
+#'
+#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#'
+#' @description Converts metadata and data from a sits tibble to a CSV file.
+#'              The CSV file will not contain the actual time
+#'              series. Its columns will be the same as those of a
+#'              CSV file used to retrieve data from
+#'              ground information ("latitude", "longitude", "start_date",
+#'              "end_date", "cube", "label"), plus the all the time series for
+#'              each data
+#' @param  data       Time series (tibble of class "sits").
+#' @param  file       Full path of the exported CSV file
+#'                    (valid file name with extension ".csv").
+#' @return            Return data.frame with CSV columns (optional)
+#'
+#' @examples
+#' csv_file <- paste0(tempdir(), "/cerrado_2classes_ts.csv")
+#' sits_timeseries_to_csv(cerrado_2classes, file = csv_file)
+#' @export
+#'
+sits_timeseries_to_csv <- function(data, file = NULL) {
+    # check the samples are valid
+    data <- .check_samples(data)
+    csv_1 <- .csv_metadata_from_samples(data)
+    csv_2 <- .predictors(data)[-2:0]
+    csv_combined <- dplyr::bind_cols(csv_1, csv_2)
+
+    # write the CSV file
+    if (.has(file))
+        utils::write.csv(csv_combined,
+                         file,
+                         row.names = FALSE,
+                         quote = FALSE)
+
+    return(csv_combined)
+}
