@@ -1,4 +1,3 @@
-#'
 #' @title Copy the images of a cube to a local directory
 #' @name sits_cube_copy
 #' @description
@@ -17,13 +16,15 @@
 #'                   ("lon_min", "lat_min", "lon_max", "lat_max").
 #' @param res        An integer value corresponds to the output
 #'                   spatial resolution of the images. Default is NULL.
-#' @param n_tries    Number of tries to download the same image. Default is 3.
+#' @param crs        Reference system for output cube (by default,
+#'                   the same CRS from the input cube is assumed)
+#' @param n_tries    Number of attempts to download the same image.
+#'                   Default is 3.
 #' @param multicores Number of cores for parallel downloading
 #'                   (integer, min = 1, max = 2048).
 #' @param output_dir Output directory where images will be saved.
 #'                   (character vector of length 1).
 #' @param progress   Logical: show progress bar?
-#' @param ...        Additional parameters to httr package.
 #' @return Copy of input data cube (class "raster cube").
 #'
 #' @examples
@@ -53,9 +54,10 @@
 #' }
 #'
 #' @export
-sits_cube_copy <- function(cube, ...,
+sits_cube_copy <- function(cube,
                            roi = NULL,
                            res = NULL,
+                           crs = NULL,
                            n_tries = 3,
                            multicores = 2L,
                            output_dir,
@@ -66,51 +68,53 @@ sits_cube_copy <- function(cube, ...,
     .check_is_raster_cube(cube)
     # Check n_tries parameter
     .check_num_min_max(x = n_tries, min = 1, max = 50)
-    # check files
+    # Check files
     .check_raster_cube_files(cube)
+    # Spatial filter
     if (.has(roi)) {
-        sf_roi <- .roi_as_sf(roi, default_crs = cube[["crs"]][[1]])
-    } else {
-        sf_roi <- NULL
-    }
-    if (inherits(output_dir, "character")) {
-        output_dir <- path.expand(output_dir)
-    }
-    .check_output_dir(output_dir)
-    .check_int_parameter(multicores, min = 1, max = 2048)
-    .check_progress(progress)
+        # if crs is not NULL, use user parameter as default
+        # else use input cube crs
+        roi <- .roi_as_sf(
+            roi,
+            default_crs = ifelse(.has(crs), crs, .cube_crs(cube))
+        )
+        cube <- .cube_filter_spatial(cube = cube, roi = roi)
 
+        if (!.cube_has_unique_resolution(cube)) {
+            .check_that(
+                .has(res),
+                msg = .conf("messages", "sits_cube_copy_different_resolutions")
+            )
+        }
+    }
+    .check_int_parameter(multicores, min = 1, max = 2048)
+    # Check Output dir
+    output_dir <- path.expand(output_dir)
+    .check_output_dir(output_dir)
+    # Check progress
+    .check_progress(progress)
     # Prepare parallel processing
     .parallel_start(workers = multicores)
     on.exit(.parallel_stop(), add = TRUE)
-
+    # Adjust tile system name
+    cube <- .cube_convert_tile_name(cube)
+    # Update token (for big tiffs and slow networks)
+    cube <- .cube_token_generator(cube)
     # Create assets as jobs
     cube_assets <- .cube_split_assets(cube)
     # Process each tile sequentially
     cube_assets <- .jobs_map_parallel_dfr(cube_assets, function(asset) {
-        # if there is a ROI which does not intersect asset, do nothing
-        if (.has(roi)) {
-            sf_asset <- .bbox_as_sf(.tile_bbox(asset))
-            if (sf::st_crs(sf_asset) != sf::st_crs(sf_roi)) {
-                sf_roi <- sf::st_transform(sf_roi, crs = .tile_crs(asset))
-            }
-            g1 <- sf::st_intersects(sf_asset, sf_roi, sparse = TRUE)
-            if (lengths(g1) == 0) {
-                return(NULL)
-            }
-        }
-        # download asset
-        local_asset <- .download_asset(
+        .download_asset(
             asset = asset,
+            roi = roi,
             res = res,
-            sf_roi = sf_roi,
             n_tries = n_tries,
-            output_dir = output_dir,
-            progress = progress, ...
+            output_dir = output_dir
         )
-        # Return local tile
-        local_asset
     }, progress = progress)
+    # Check and return
     .check_empty_data_frame(cube_assets)
-    .cube_merge_tiles(cube_assets)
+    cube_assets <- .cube_merge_tiles(cube_assets)
+    # Revert tile system name
+    .cube_revert_tile_name(cube_assets)
 }
