@@ -10,6 +10,7 @@
 #'              and applies a Bayesian smoothing function.
 #'
 #' @param  cube              Probability data cube.
+#' @param  ...               Other parameters for specific functions.
 #' @param  window_size       Size of the neighborhood
 #'                           (integer, min = 3, max = 21)
 #' @param  neigh_fraction    Fraction of neighbors with high probabilities
@@ -18,6 +19,9 @@
 #' @param  smoothness        Estimated variance of logit of class probabilities
 #'                           (Bayesian smoothing parameter)
 #'                           (integer vector or scalar, min = 1, max = 200).
+#' @param  exclusion_mask    Areas to be excluded from the classification
+#'                           process. It can be defined as a sf object or a
+#'                           shapefile.
 #' @param  memsize           Memory available for classification in GB
 #'                           (integer, min = 1, max = 16384).
 #' @param  multicores        Number of cores to be used for classification
@@ -59,16 +63,22 @@
 #'     plot(label_cube)
 #' }
 #' @export
-sits_smooth <- function(cube,
-                        window_size = 7L,
-                        neigh_fraction = 0.5,
-                        smoothness = 10L,
-                        memsize = 4L,
-                        multicores = 2L,
-                        output_dir,
-                        version = "v1") {
+sits_smooth <- function(cube, ...) {
     # set caller for error messages
     .check_set_caller("sits_smooth")
+    UseMethod("sits_smooth", cube)
+}
+#' @rdname sits_smooth
+#' @export
+sits_smooth.probs_cube <- function(cube, ...,
+                                   window_size = 9L,
+                                   neigh_fraction = 0.5,
+                                   smoothness = 20L,
+                                   exclusion_mask = NULL,
+                                   memsize = 4L,
+                                   multicores = 2L,
+                                   output_dir,
+                                   version = "v1") {
     # Check if cube has probability data
     .check_raster_cube_files(cube)
     # check window size
@@ -92,18 +102,6 @@ sits_smooth <- function(cube,
     if (length(smoothness) == 1) {
         smoothness <- rep(smoothness, nlabels)
     }
-    UseMethod("sits_smooth", cube)
-}
-#' @rdname sits_smooth
-#' @export
-sits_smooth.probs_cube <- function(cube,
-                                   window_size = 7L,
-                                   neigh_fraction = 0.5,
-                                   smoothness = 10L,
-                                   memsize = 4L,
-                                   multicores = 2L,
-                                   output_dir,
-                                   version = "v1") {
     # version is case-insensitive in sits
     version <- tolower(version)
     # get nlabels
@@ -112,26 +110,29 @@ sits_smooth.probs_cube <- function(cube,
     if (length(smoothness) == 1) {
         smoothness <- rep(smoothness, nlabels)
     }
+
+    # The following functions define optimal parameters for parallel processing
+    #
     # Get block size
     block <- .raster_file_blocksize(.raster_open_rast(.tile_path(cube)))
     # Overlapping pixels
     overlap <- ceiling(window_size / 2) - 1
     # Check minimum memory needed to process one block
-    job_memsize <- .jobs_memsize(
-        job_size = .block_size(block = block, overlap = overlap),
+    job_block_memsize <- .jobs_block_memsize(
+        block_size = .block_size(block = block, overlap = overlap),
         npaths = length(.tile_labels(cube)) * 2,
         nbytes = 8,
         proc_bloat = .conf("processing_bloat_cpu")
     )
     # Update multicores parameter
     multicores <- .jobs_max_multicores(
-        job_memsize = job_memsize,
+        job_block_memsize = job_block_memsize,
         memsize = memsize,
         multicores = multicores
     )
     # Update block parameter
     block <- .jobs_optimal_block(
-        job_memsize = job_memsize,
+        job_block_memsize = job_block_memsize,
         block = block,
         image_size = .tile_size(.tile(cube)),
         memsize = memsize,
@@ -147,6 +148,7 @@ sits_smooth.probs_cube <- function(cube,
         window_size = window_size,
         neigh_fraction = neigh_fraction,
         smoothness = smoothness,
+        exclusion_mask = exclusion_mask,
         multicores = multicores,
         memsize = memsize,
         output_dir = output_dir,
@@ -155,50 +157,27 @@ sits_smooth.probs_cube <- function(cube,
 }
 #' @rdname sits_smooth
 #' @export
-sits_smooth.raster_cube <- function(cube,
-                                    window_size = 7L,
-                                    neigh_fraction = 0.5,
-                                    smoothness = 10L,
-                                    memsize = 4L,
-                                    multicores = 2L,
-                                    output_dir,
-                                    version = "v1") {
+sits_smooth.probs_vector_cube <- function(cube, ...) {
+    stop(.conf("messages", "sits_probs_vector_cube"))
+}
+#' @rdname sits_smooth
+#' @export
+sits_smooth.raster_cube <- function(cube,...) {
     stop(.conf("messages", "sits_smooth_default"))
 }
 #' @rdname sits_smooth
 #' @export
-sits_smooth.derived_cube <- function(cube, window_size = 7L,
-                                     neigh_fraction = 0.5,
-                                     smoothness = 10L,
-                                     memsize = 4L,
-                                     multicores = 2L,
-                                     output_dir,
-                                     version = "v1") {
+sits_smooth.derived_cube <- function(cube, ...) {
     stop(.conf("messages", "sits_smooth_default"))
 }
 #' @rdname sits_smooth
 #' @export
-sits_smooth.default <- function(cube,
-                                window_size = 7L,
-                                neigh_fraction = 0.5,
-                                smoothness = 10L,
-                                memsize = 4L,
-                                multicores = 2L,
-                                output_dir,
-                                version = "v1") {
+sits_smooth.default <- function(cube,...) {
     cube <- tibble::as_tibble(cube)
     if (all(.conf("sits_cube_cols") %in% colnames(cube)))
         cube <- .cube_find_class(cube)
     else
         stop(.conf("messages", "sits_smooth_default"))
-
-    cube <- sits_smooth(cube,
-                        window_size = 7L,
-                        neigh_fraction = 0.5,
-                        smoothness = 10L,
-                        memsize = 4L,
-                        multicores = 2L,
-                        output_dir,
-                        version = "v1")
+    cube <- sits_smooth(cube,...)
     return(cube)
 }
