@@ -97,7 +97,7 @@ test_that("Accuracy areas", {
     data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
     cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         progress = FALSE
     )
@@ -109,8 +109,6 @@ test_that("Accuracy areas", {
         multicores = 1,
         progress = FALSE
     )
-
-
     expect_true(all(file.exists(unlist(probs_cube$file_info[[1]]$path))))
     tc_obj <- .raster_open_rast(probs_cube$file_info[[1]]$path[[1]])
     expect_true(nrow(tc_obj) == .tile_nrows(probs_cube))
@@ -159,6 +157,21 @@ test_that("Accuracy areas", {
         expected = 0.75,
         tolerance = 0.5
     )
+
+    # alternative: use a `sf` object
+    samples_sf <- samples_csv |>
+                    sf::st_as_sf(
+                        coords = c("longitude", "latitude"), crs = 4326
+                    ) |>
+                    dplyr::rename("geom" = "geometry")
+    as3 <- sits_accuracy(label_cube, validation = samples_sf)
+
+    expect_true(as.numeric(as3$area_pixels["Forest"]) >
+                    as3$area_pixels["Pasture"])
+    expect_equal(as.numeric(as3$accuracy$overall),
+                 expected = 0.75,
+                 tolerance = 0.5
+    )
 })
 
 test_that("Accuracy areas when samples labels do not match cube labels", {
@@ -170,7 +183,7 @@ test_that("Accuracy areas when samples labels do not match cube labels", {
 
     cube <- sits_cube(
         source = "BDC",
-        collection = "MOD13Q1-6",
+        collection = "MOD13Q1-6.1",
         data_dir = data_dir,
         multicores = 2,
         memsize = 4
