@@ -1,8 +1,9 @@
-test_that("Testing normalized index generation", {
+test_that("Testing index generation", {
+    # Create a cube with two bands
     s2_cube <- tryCatch(
         {
             sits_cube(
-                source = "MPC",
+                source = "AWS",
                 collection = "SENTINEL-2-L2A",
                 tiles = "20LKP",
                 bands = c("B05", "B8A", "CLOUD"),
@@ -18,32 +19,37 @@ test_that("Testing normalized index generation", {
 
     testthat::skip_if(
         purrr::is_null(s2_cube),
-        "MPC is not accessible"
+        "AWS is not accessible"
     )
 
     dir_images <- paste0(tempdir(), "/images/")
     if (!dir.exists(dir_images)) {
         suppressWarnings(dir.create(dir_images))
     }
+
     unlink(list.files(dir_images,
                       pattern = "\\.tif$",
                       full.names = TRUE
     ))
-    expect_warning({gc_cube <- sits_regularize(
+    # Regularize cube
+    gc_cube <- suppressWarnings(
+        sits_regularize(
             cube = s2_cube,
             output_dir = dir_images,
             res = 160,
             period = "P1M",
             multicores = 2,
             progress = FALSE
-    )})
-
+        )
+    )
+    # Calculate EVI
     gc_cube_new <- sits_apply(gc_cube,
                               EVI = 2.5 * (B8A - B05) / (B8A + 2.4 * B05 + 1),
                               multicores = 1,
                               output_dir = dir_images
     )
 
+    # Test EVI
     expect_true(all(sits_bands(gc_cube_new) %in% c("EVI", "B05", "B8A")))
 
     timeline <- sits_timeline(gc_cube_new)
@@ -76,121 +82,27 @@ test_that("Testing normalized index generation", {
     evi2_calc_150 <- 2.5 * (b8a_150 - b05_150) / (b8a_150 + 2.4 * b05_150 + 1)
     expect_equal(evi2_150, evi2_calc_150, tolerance = 0.001)
 
-    bbox_cube <- sits_bbox(gc_cube_new, as_crs = "EPSG:4326")
-    lats <- runif(10, min = bbox_cube[["ymin"]], max = bbox_cube[["ymax"]])
-    longs <- runif(10, min = bbox_cube[["xmin"]], max = bbox_cube[["xmax"]])
 
-    timeline <- sits_timeline(gc_cube_new)
-    start_date <- timeline[1]
-    end_date <- timeline[length(timeline)]
-
-    # test with data frame
-    #
-    gc_cube2 <- gc_cube
-    class(gc_cube2) <- "data.frame"
-
-    gc_cube2 <- sits_apply(gc_cube2,
-                              NDRE = (B8A - B05) / (B8A + B05),
-                              multicores = 1,
-                              output_dir = dir_images
-    )
-    expect_true("NDRE" %in% sits_bands(gc_cube2))
-
-    csv_tb <- purrr::map2_dfr(lats, longs, function(lat, long) {
-        tibble::tibble(
-            longitude = long,
-            latitude = lat,
-            start_date = start_date,
-            end_date = end_date,
-            label = "NoClass"
-        )
-    })
-    csv_file <- paste0(tempdir(), "/csv_gc_cube.csv")
-    write.csv(csv_tb, file = csv_file)
-
-    evi_tibble <- sits_get_data(gc_cube_new, csv_file, multicores = 1,
-                                progress = FALSE)
-    evi_tibble_2 <- sits_apply(
-        evi_tibble,
-        EVI_NEW = 2.5 * (B8A - B05) / (B8A + 2.4 * B05 + 1)
-    )
-
-    values_evi2 <- .tibble_time_series(evi_tibble_2)$EVI
-    values_evi2_new <- .tibble_time_series(evi_tibble_2)$EVI_NEW
-    expect_equal(values_evi2, values_evi2_new, tolerance = 0.001)
-})
-
-test_that("Testing non-normalized index generation", {
-    data_dir <- system.file("extdata/raster/mod13q1", package = "sits")
-    cube <- sits_cube(
-        source = "BDC",
-        collection = "MOD13Q1-6.1",
-        data_dir = data_dir,
-        progress = FALSE
-    )
-
-
-    dir_images <- paste0(tempdir(), "/images/")
-    if (!dir.exists(dir_images)) {
-        suppressWarnings(dir.create(dir_images))
-    }
-    gc_cube_new <- sits_apply(cube,
-                              XYZ = 1 / NDVI * 0.25,
+    gc_cube_new <- sits_apply(gc_cube_new,
+                              CIRE = B8A / B05 - 1,
                               normalized = FALSE,
                               multicores = 1,
                               output_dir = dir_images
     )
+    expect_true(all(sits_bands(gc_cube_new) %in% c("CIRE", "EVI", "B05", "B8A")))
 
-    expect_true(all(sits_bands(gc_cube_new) %in% c("NDVI", "XYZ")))
+    file_info_cire <- .fi(gc_cube_new) |> .fi_filter_bands(bands = "CIRE")
+    cire_band_1 <- .raster_open_rast(file_info_cire$path[[1]])
 
-    file_info_ndvi <- .fi(gc_cube_new) |> .fi_filter_bands(bands = "NDVI")
-    ndvi_band_1 <- .raster_open_rast(file_info_ndvi$path[[1]])
+    cire_100 <- as.numeric(cire_band_1[100])
+    cire_calc_100 <- b8a_100 / b05_100 - 1
+    expect_equal(cire_100, cire_calc_100, tolerance = 0.001)
 
-    file_info_xyz <- .fi(gc_cube_new) |> .fi_filter_bands(bands = "XYZ")
-    xyz_band_1 <- .raster_open_rast(file_info_xyz$path[[1]])
+    cire_150 <- as.numeric(cire_band_1[150])
+    cire_calc_150 <- b8a_150 / b05_150 - 1
+    expect_equal(cire_150, cire_calc_150, tolerance = 0.001)
 
-    scale_factor <- 10000
-    ndvi_100 <- as.numeric(ndvi_band_1[100] / 10000)
-    xyz_100 <- as.numeric(xyz_band_1[100] / 10000) * scale_factor
-
-    xyz_calc_100 <- 1 / ndvi_100 * 0.25
-    expect_equal(xyz_100, xyz_calc_100, tolerance = 0.001)
-
-    ndvi_150 <- as.numeric(ndvi_band_1[150] / 10000)
-    xyz_150 <- as.numeric(xyz_band_1[150] / 10000) * scale_factor
-
-    xyz_calc_150 <- 1 / ndvi_150 * 0.25
-    expect_equal(xyz_150, xyz_calc_150, tolerance = 0.001)
-
-    bbox_cube <- sits_bbox(gc_cube_new, as_crs = "EPSG:4326")
-    lats <- runif(10, min = bbox_cube[["ymin"]], max = bbox_cube[["ymax"]])
-    longs <- runif(10, min = bbox_cube[["xmin"]], max = bbox_cube[["xmax"]])
-
-    timeline <- sits_timeline(gc_cube_new)
-    start_date <- timeline[1]
-    end_date <- timeline[length(timeline)]
-
-    csv_tb <- purrr::map2_dfr(lats, longs, function(lat, long) {
-        tibble::tibble(
-            longitude = long,
-            latitude = lat,
-            start_date = start_date,
-            end_date = end_date,
-            label = "NoClass"
-        )
-    })
-    csv_file <- paste0(tempdir(), "/csv_gc_cube2.csv")
-    write.csv(csv_tb, file = csv_file)
-
-    xyz_tibble <- sits_get_data(gc_cube_new, csv_file, progress = FALSE)
-    xyz_tibble_2 <- sits_apply(
-        xyz_tibble,
-        XYZ_NEW = 1 / NDVI * 0.25
-    )
-
-    values_xyz2 <- .tibble_time_series(xyz_tibble)$XYZ
-    values_xyz_new <- .tibble_time_series(xyz_tibble_2)$XYZ_NEW
-    expect_equal(values_xyz2, values_xyz_new, tolerance = 0.001)
+    unlink(dir_images, recursive = TRUE)
 })
 
 test_that("Kernel functions", {
@@ -222,15 +134,15 @@ test_that("Kernel functions", {
     # Recovery
     Sys.setenv("SITS_DOCUMENTATION_MODE" = "FALSE")
     expect_message({
-                cube_median <- sits_apply(
-                    data = cube,
-                    output_dir = tempdir(),
-                    NDVI_MEDIAN = w_median(NDVI),
-                    window_size = 3,
-                    memsize = 4,
-                    multicores = 1
-                )
-            }
+        cube_median <- sits_apply(
+            data = cube,
+            output_dir = tempdir(),
+            NDVI_MEDIAN = w_median(NDVI),
+            window_size = 3,
+            memsize = 4,
+            multicores = 1
+        )
+    }
     )
     cube_mean <- sits_apply(
         data = cube,
@@ -326,6 +238,11 @@ test_that("Error", {
     if (!dir.exists(output_dir)) {
         dir.create(output_dir)
     }
+    unlink(list.files(output_dir,
+                      pattern = "\\.tif$",
+                      full.names = TRUE
+    ))
+
     Sys.setenv("SITS_DOCUMENTATION_MODE" = "FALSE")
     expect_warning({
         cube_median <- sits_apply(
@@ -347,4 +264,5 @@ test_that("Error", {
     )
     expect_error(sits_apply(sinop_probs))
 
+    unlink(output_dir, recursive = TRUE)
 })
