@@ -259,12 +259,12 @@ test_that("Creating Sentinel-1 RTC cubes from DEA using tiles", {
     )
 
     bbox <- sits_bbox(cube_s1_rtc)
-    roi_cube_s1 <- sits_mgrs_to_roi(c("36NWJ"))
+    roi_cube_s1 <- sits_tiles_to_roi(c("36NWJ"))
 
-    expect_true(bbox[["xmin"]] < roi_cube_s1[["lon_min"]])
-    expect_true(bbox[["xmax"]] > roi_cube_s1[["lon_max"]])
-    expect_true(bbox[["ymin"]] < roi_cube_s1[["lat_min"]])
-    expect_true(bbox[["ymax"]] > roi_cube_s1[["lat_max"]])
+    expect_true(bbox[["xmin"]] < roi_cube_s1[["xmin"]])
+    expect_true(bbox[["xmax"]] > roi_cube_s1[["xmax"]])
+    expect_true(bbox[["ymin"]] < roi_cube_s1[["ymin"]])
+    expect_true(bbox[["ymax"]] > roi_cube_s1[["ymax"]])
     expect_true(all(c("VV") %in% sits_bands(cube_s1_rtc)))
 
     r_obj <- .raster_open_rast(cube_s1_rtc$file_info[[1]]$path[[1]])
@@ -289,12 +289,12 @@ test_that("Creating Sentinel-1 RTC cubes from DEA using tiles", {
     expect_true(all("EPSG:32636" %in% cube_s1_reg$crs))
 
     bbox <- sits_bbox(cube_s1_reg, as_crs = "EPSG:4326")
-    roi_cube_s1 <- sits_mgrs_to_roi("36NWJ")
+    roi_cube_s1 <- sits_tiles_to_roi("36NWJ")
 
-    expect_equal(bbox[["xmin"]], roi_cube_s1[["lon_min"]], tolerance = 0.01)
-    expect_equal(bbox[["xmax"]], roi_cube_s1[["lon_max"]], tolerance = 0.01)
-    expect_equal(bbox[["ymin"]], roi_cube_s1[["lat_min"]], tolerance = 0.01)
-    expect_equal(bbox[["ymax"]], roi_cube_s1[["lat_max"]], tolerance = 0.01)
+    expect_equal(bbox[["xmin"]], roi_cube_s1[["xmin"]], tolerance = 0.01)
+    expect_equal(bbox[["xmax"]], roi_cube_s1[["xmax"]], tolerance = 0.01)
+    expect_equal(bbox[["ymin"]], roi_cube_s1[["ymin"]], tolerance = 0.01)
+    expect_equal(bbox[["ymax"]], roi_cube_s1[["ymax"]], tolerance = 0.01)
 
     expect_true(all(c("VV") %in% sits_bands(cube_s1_reg)))
 })
