@@ -38,8 +38,7 @@ test_that("Labels from a STAC class cube", {
 
     labels <- summary(class_cube)
     expect_true("Tree_Cover" %in% sits_labels(class_cube))
-    expect_equal(sum(labels$count), 2555916)
-    expect_equal(labels$class[2], "Shrubland")
+    expect_equal(labels$class[2], "Moss_and_Lichen")
 })
 
 test_that("Relabel", {
