@@ -1,4 +1,5 @@
 test_that("Plot Time Series and Images", {
+    set.seed(290356)
     cerrado_ndvi <- sits_select(cerrado_2classes, "NDVI")
 
     p <- plot(cerrado_ndvi[1, ])
@@ -46,14 +47,18 @@ test_that("Plot Time Series and Images", {
         progress = FALSE
     )
     p <- plot(sinop, band = "NDVI", palette = "RdYlGn")
-    expect_equal(p$tm_shape$shp_name, "st")
-    expect_equal(p$tm_raster$palette, "RdYlGn")
-    expect_equal(p$tm_grid$grid.projection, 4326)
+    rast_ndvi <- p[[1]]$shp
+    expect_equal(nrow(rast_ndvi), 147)
 
     p_rgb <- plot(sinop, red = "NDVI", green = "NDVI", blue = "NDVI")
+    rast_rgb <- p_rgb[[1]]$shp
+    expect_true("SpatRaster" %in% class(rast_rgb))
 
-    expect_equal(p_rgb$tm_shape$shp_name, "rgb_st")
-    expect_equal(p_rgb$tm_grid$grid.projection, 4326)
+    p_multi <- plot(sinop, band = "NDVI",
+                    dates = c("2013-09-14", "2013-10-16", "2013-11-17"))
+
+    rast_multi <- p_multi[[1]]$shp
+    expect_true("SpatRaster" %in% class(rast_multi))
 
     sinop_probs <- suppressMessages(
         sits_classify(
@@ -66,64 +71,32 @@ test_that("Plot Time Series and Images", {
         )
     )
     p_probs <- plot(sinop_probs)
-    expect_equal(p_probs$tm_raster$palette, "YlGn")
-    expect_equal(length(p_probs$tm_raster$title), 4)
-    expect_equal(p_probs$tm_layout$legend.bg.color, "white")
+    rast_probs <- p_probs[[1]]$shp
+    expect_equal(terra::nlyr(rast_probs), 4)
 
     p_probs_f <- plot(sinop_probs, labels = "Forest")
-    expect_equal(p_probs_f$tm_raster$palette, "YlGn")
-    expect_equal(length(p_probs_f$tm_raster$title), 1)
-    expect_equal(p_probs_f$tm_layout$legend.bg.color, "white")
+    rast_probs_f <- p_probs_f[[1]]$shp
+    expect_equal(terra::nlyr(rast_probs_f), 1)
 
     sinop_uncert <- sits_uncertainty(sinop_probs,
         output_dir = tempdir()
     )
-
     p_uncert <- plot(sinop_uncert, palette = "Reds", rev = FALSE)
-
-    expect_equal(p_uncert$tm_raster$palette, "Reds")
-    expect_equal(length(p_uncert$tm_raster$title), 1)
-    expect_equal(p_uncert$tm_layout$legend.bg.color, "white")
+    rast_uncert <- p_uncert[[1]]$shp
+    expect_equal(terra::nlyr(rast_uncert), 1)
 
     sinop_labels <- sits_label_classification(
         sinop_probs,
         output_dir = tempdir(),
         progress = FALSE
     )
-
-    p4 <- plot(sinop_labels)
-    expect_equal(p4$tm_grid$grid.projection, 4326)
-    expect_equal(p4$tm_raster$n, 5)
-    expect_true(p4$tm_shape$check_shape)
-})
-
-test_that("Plot class cube from STAC", {
-    to_class <- .try(
-        {
-            sits_cube(
-                source     = "TERRASCOPE",
-                collection = "WORLD-COVER-2021",
-                bands      = "CLASS",
-                roi        = c("lon_min" = -62.7,
-                               "lon_max" = -62.5,
-                               "lat_min" = -8.83 ,
-                               "lat_max" = -8.70
-                ),
-                progress   = FALSE
-            )
-        },
-        .default = NULL
-    )
-    testthat::skip_if(purrr::is_null(to_class),
-                      message = "TERRASCOPE is not accessible"
-    )
-    p1 <- plot(to_class)
-    expect_equal(p1$tm_grid$grid.projection, 4326)
-    expect_equal(p1$tm_raster$n, 5)
-    expect_true(p1$tm_shape$check_shape)
+    p_class <- plot(sinop_labels)
+    rast_class <- p_class[[1]]$shp
+    expect_true("SpatRaster" %in% class(rast_class))
 })
 
 test_that("Plot Accuracy", {
+    set.seed(290356)
     # show accuracy for a set of samples
     train_data <- sits_sample(samples_modis_ndvi, frac = 0.5)
     test_data  <- sits_sample(samples_modis_ndvi, frac = 0.5)
@@ -134,30 +107,16 @@ test_that("Plot Accuracy", {
     # calculate accuracy
     acc <- sits_accuracy(points_class)
     # plot accuracy
-    p <- plot(acc)
-    expect_equal(p$labels$title, "Confusion matrix")
-    expect_equal(p$labels$x, "Class")
-    expect_equal(p$labels$y, "Agreement with reference")
-    expect_equal(p$theme$line$colour, "black")
+    p_acc <- plot(acc)
+    expect_equal(p_acc$labels$title, "Confusion matrix")
+
 })
 
 test_that("Plot Models", {
     set.seed(290356)
     rfor_model <- sits_train(samples_modis_ndvi, ml_method = sits_rfor())
     p_model <- plot(rfor_model)
-    expect_true(all(p_model$data$variable %in% c(
-        "NDVI1", "NDVI2", "NDVI3",
-        "NDVI4", "NDVI5", "NDVI6",
-        "NDVI7", "NDVI8", "NDVI9",
-        "NDVI10", "NDVI11", "NDVI12"
-    )))
-    expect_true(all(p_model$data$minimal_depth[1:2] %in% c(0, 1)))
-
-    xgb_model <- sits_train(samples_modis_ndvi, ml_method = sits_xgboost())
-    p_xgb <- plot(xgb_model)
-    expect_equal(p_xgb$x$config$engine, "dot")
-    expect_false(p_xgb$sizingPolicy$browser$fill)
-    expect_false(p_xgb$sizingPolicy$browser$external)
+    expect_equal(p_model$labels$title, "Distribution of minimal depth and its mean")
 })
 
 test_that("Dendrogram Plot", {
@@ -167,7 +126,6 @@ test_that("Dendrogram Plot", {
         samples = samples,
         bands = c("NDVI", "EVI")
     )
-
     best_cut <- .cluster_dendro_bestcut(samples, cluster)
 
     dend <- plot(samples,
@@ -175,10 +133,10 @@ test_that("Dendrogram Plot", {
         cutree_height = best_cut["height"],
         palette = "RdYlGn"
     )
-    expect_equal(class(dend), "dendrogram")
+    expect_true("dendrogram" %in% class(dend))
 })
-
 test_that("Plot torch model", {
+    set.seed(290356)
     model <- sits_train(
         samples_modis_ndvi,
         sits_mlp(
@@ -187,43 +145,22 @@ test_that("Plot torch model", {
             epochs = 50
         )
     )
-    pk <- plot(model)
-    expect_true(length(pk$layers) == 2)
-    expect_true(pk$labels$colour == "data")
-    expect_true(pk$labels$x == "epoch")
-    expect_true(pk$labels$y == "value")
-})
-
-test_that("Plot series with NA", {
-    cerrado_ndvi <- cerrado_2classes |>
-        sits_select(bands = "NDVI") |>
-        dplyr::filter(label == "Cerrado")
-    cerrado_ndvi_1 <- cerrado_ndvi[1, ]
-    ts <- cerrado_ndvi_1$time_series[[1]]
-    ts[1, 2] <- NA
-    ts[10, 2] <- NA
-    cerrado_ndvi_1$time_series[[1]] <- ts
-    pna <- suppressWarnings(plot(cerrado_ndvi_1))
-    expect_true(pna$labels$x == "Index")
-    expect_true(pna$labels$y == "value")
+    p_torch <- plot(model)
+    expect_equal(p_torch$labels$x, "epoch")
+    expect_equal(p_torch$labels$y, "value")
 })
 
 test_that("SOM map plot", {
     set.seed(1234)
-    som_map <-
-        suppressWarnings(sits_som_map(
+    som_map <- suppressWarnings(sits_som_map(
             cerrado_2classes,
             grid_xdim = 5,
             grid_ydim = 5
         ))
 
-    p <- suppressWarnings(plot(som_map))
-    expect_true(all(names(p$rect) %in% c("w", "h", "left", "top")))
-
-    pc <- plot(som_map, type = "mapping")
-    expect_true(all(names(pc$rect) %in% c("w", "h", "left", "top")))
+    p_som_map <- plot(som_map)
+    expect_true(any("Cerrado" %in% p_som_map$som_properties$neuron_label))
 })
-
 test_that("SOM evaluate cluster plot", {
     set.seed(1234)
     som_map <-
@@ -232,10 +169,9 @@ test_that("SOM evaluate cluster plot", {
             grid_xdim = 5,
             grid_ydim = 5
         ))
-
     cluster_purity_tb <- sits_som_evaluate_cluster(som_map)
 
-    p <- plot(cluster_purity_tb)
-    expect_equal(p$labels$title, "Confusion by cluster")
-    expect_equal(p$labels$y, "Percentage of mixture")
+    p_purity <- plot(cluster_purity_tb)
+    expect_equal(p_purity$labels$title,
+                 "Confusion by cluster")
 })
